/*----------------------------------------------------------------------------------------------------  
   Copyright (c) 2003 ACEECA Limited. All rights reserved.
  
   File: 		BCS2ScannerLib.h
  
   Version:	1.4.3b
  
   Release: 16th March 2005
  
   Description:

  		Header file for the BCS2 laser barcode scanner API library. Use this file in conjunction
  		with your project file to incorporate the bar code functionality of an IDV-BCS2
  		unit from ACEECA Limited. The library checks the hardware to make sure the 
  		Meazura features are present, an error code is returned otherwise. Below is a 
 			summary of the functions included in the library:
 			
 			BCS2LibOpen: 
				Opens the BarCodeScanner library, creates and initializes the globals.
	 			This function must be called before any other BarCodeScanner Library functions,
	 			with the exception of BCS2LibGetLibAPIVersion. This library requires at least the 
	 			MeazuraLib_V200b.prc shared library to work - an error message will 
	 			be returned if the library is of the wrong version. BCS2LibClose must be called
	 			if this is the case.
			
			BCS2LibClose:
 				Closes the BarCodeScanner libary, frees globals. If other applications still 
 				have the library open, decrements the reference count and returns errBCS2LibStillOpen.

  		BCS2LibSleep:
				Handles system sleep event.

			BCS2LibWake:
				Handles system wake event.

			BCS2LibGetLibAPIVersion:
				Get the BCS2 library API version.  

			BCS2LibTriggerOn:
				Triggers the BCS2 module to start reading a barcode. When a valid barcode is received, a
				BCS2BarCodeReadyNotification notification will be broadcast to whoever has registered to 
				receive it. The registering of the notification should be done before calling this function. 
				Please refer to the "Notification Manager" on page 711 of the Palm OS Programmers' API Reference
				for more information on how to use notifications. 

			BCS2LibTriggerOff:
				Tells the BCS2 module to stop triggering immediately.  

			BCS2LibReset:
				Resets the BCS2 module. This function may be useful if the module doesn't seem to respond and may
				have gone into a unknown state.

			BCS2LibSetToFactoryDefaults:
				Sets the BCS2 module to its ACEECA's factory defaults. This will set up the module 
				with the same settings as it left ACEECA Limited. It has been included for cases where the 
				module have been reconfigured by a third party and factory defaults are required.

			BCS2LibChangeSettings:
				This allows the caller to change the barcode scanner module settings eg. symbologies etc.				
				It accepts configuration strings that will be provided.

		 History:
	 	03-dec-03 HD: Release beta version BarCodeScannerLib_V100b.prc (120303-1325)
	 	10-dec-03	HD: Modified the library so that the triggering can be better controlled, ie trigger on,
	 								release off. Released as BarCodeScannerLib_V110b.prc (121103-1019)
	 	22-Jan-04	HD:	Corrected issue of fatal exceptions when a barcode was received before
	 								trigger button was pressed. 							
	 	23-Jan-04	HD: Found that UART interrupts were turning off when power was turned off, this is now fixed.
 		23-Feb-04	HD: Added BCS2LibChangeSettings which allows developers access to configuring the
 									barcode scanner module using a configuration string.
 							HD:	Also made this header file compatible with GCC compilers.		
----------------------------------------------------------------------------------------------------*/  

#ifndef __BCS2_LIB_H__
#define __BCS2_LIB_H__


// If we're actually compiling the library code, then we need to
// eliminate the trap glue that would otherwise be generated from
// this header file in order to prevent compiler errors in CW Pro 2.
#ifdef BUILDING_SAMPLE_LIB
	#define SAMPLE_LIB_TRAP(trapNum)
#else
	#define SAMPLE_LIB_TRAP(trapNum) SYS_TRAP(trapNum)
#endif


// Palm OS common definitions
#include <PalmTypes.h>
#include <SystemResources.h>

#ifdef __MWERKS__
#pragma mark Library Version
#endif
// LIBRARY VERSION
//
// The library version scheme follows the system versioning scheme.
// See sysMakeROMVersion and friends in SystemMgr.h.
//
// For reference:
//
// 0xMMmfsbbb, where MM is major version, m is minor version
// f is bug fix, s is stage: 3-release,2-beta,1-alpha,0-development,
// bbb is build number for non-releases 
// V1.12b3   would be: 0x01122003
// V2.00a2   would be: 0x02001002
// V1.01     would be: 0x01013000
#define BCS2LibVersion	sysMakeROMVersion(1, 4, 3, sysROMStageBeta, 1)


#ifdef __MWERKS__
#pragma mark Creator Codes
#endif
/********************************************************************
 * Type and creator of BarCodeScanner Library database
 ********************************************************************/
#define		BCS2LibCreatorID							'BcAp'		// Bar Code scanner Library database creator
#define		BCS2LibTypeID									'libr'		// Standard library database type

/********************************************************************
 * Internal library name which can be passed to SysLibFind()
 ********************************************************************/
#define		BCS2LibName										"BCS2 API Library"		

#ifdef __MWERKS__
#pragma mark Notifications
#endif
/********************************************************************
 * BCS2 notification
 ********************************************************************/
#define		BCS2BarCodeReadyNotification	'BcsN'		// Bar code scanner notification


#ifdef __MWERKS__
#pragma mark Error Codes
#endif
/************************************************************
 * Bar Code Scanner Library error codes
 *************************************************************/
#define errBCS2ParamError							(appErrorClass | 0x1)		// invalid parameter
#define errBCS2LibNotOpen							(appErrorClass | 0x2)		// returned if library is not openned
#define errBCS2LibStillOpen						(appErrorClass | 0x3)		// returned from MzLibClose() if the library is still open by others
#define errBCS2MemoryError						(appErrorClass | 0x4)		// memory error occurred
#define errBCS2HwFuncNotSupported			(appErrorClass | 0x5)		// the function being accessed is not available on the current hardware
#define errBCS2WrongMzLibVersion			(appErrorClass | 0x6)		// the wrong Meazura library version has been loaded
#define errBCS2MzLibLoadError					(appErrorClass | 0x7)		// an error occured opening the meazura library
#define errBCS2MzScannerError					(appErrorClass | 0x8)		// scanner engine comms error

/********************************************************************
 * Meazura key bit definitions
 ********************************************************************/
#define		MzLeftKeyBit					keyBitHard1		
#define		MzCentreKeyBit				keyBitHard2		
#define		MzRightKeyBit					keyBitHard3	 
#define		MzUpKeyBit			 			keyBitPageUp
#define		MzDownKeyBit		 			keyBitPageDown
#define		MzPowerKeyBit		 			keyBitPower

/********************************************************************
 * Meazura virtual keys definitions
 ********************************************************************/
#define		MzVLeftKey						chrLeftArrow		
#define		MzVCentreKey					vchrHard1		
#define		MzVRightKey						chrRightArrow	 
#define		MzVUpKey			 				vchrPageUp
#define		MzVDownKey		 				vchrPageDown
#define		MzVPowerKey		 				vchrAutoOff


#ifdef __MWERKS__
#pragma mark Library Traps
#endif
#define	BCS2LibTrapGetLibAPIVersion 		(sysLibTrapCustom + 0)
#define	BCS2LibTrapTriggerOn						(sysLibTrapCustom + 1)
#define	BCS2LibTrapTriggerOff						(sysLibTrapCustom + 2)
#define	BCS2LibTrapReset								(sysLibTrapCustom + 3)
#define	BCS2LibTrapSetToFactoryDefaults	(sysLibTrapCustom + 4)
#define BCS2LibTrapChangeSettings				(sysLibTrapCustom + 5)
#define BCS2LibTrapLast									(sysLibTrapCustom + 6)


#ifdef __MWERKS__
#pragma mark Public Definitions 
#endif
/********************************************************************
 * Public Definitions
 ********************************************************************/
#define BCS2MaxBarCodeSize 100

/********************************************************************
 * API Prototypes
 ********************************************************************/

#ifdef __cplusplus
extern "C" {
#endif


//--------------------------------------------------
// Standard library open, close, sleep and wake functions
//--------------------------------------------------
#ifdef __MWERKS__
#pragma mark Function Prototypes
#endif

/************************************************************
 *
 *  FUNCTION: BCS2LibOpen
 *
 *  DESCRIPTION:	Opens the BarCodeScanner library, creates and initializes the globals.
 *						This function must be called before any other BarCodeScanner Library functions,
 *						with the exception of BCS2LibGetLibAPIVersion.
 *						Does not turn on module power
 *
 *						If BCS2LibOpen fails, do not call any other BarCodeScanner library API functions.
 *						If BCS2LibOpen succeeds, call BCS2LibClose when you are done using
 *						the library to enable it to release critical system resources.
 *
 *  LIBRARY DEVELOPER NOTES:
 *
 *						The library's "open" and "close" functions should *not* take an excessive
 *						amount of time to complete.  If the processing time for either of these
 *						is lengthy, consider creating additional library API function(s) to handle
 *						the time-consuming chores.
 *
 *
 *  PARAMETERS:		
 *						refNum	-- BarCodeScanner library reference number returned by SysLibLoad()
 *										   or SysLibFind().
 *
 *  CALLED BY:		anyone who wants to use this library
 *
 *  RETURNS:	0										-- no error
 *						errBCS2MemoryError	-- not enough memory to initialize
 *
 *
 *  CREATED:	2-Dec-03 
 *
 *  BY: 			Hemon Dey
 *
 *  REVISION HISTORY:
 *			Name	Date		Description
 *			----	----		-----------
 *
 *************************************************************/
extern Err BCS2LibOpen(UInt16 refNum)
				SAMPLE_LIB_TRAP(sysLibTrapOpen);
				
/************************************************************
 *
 *  FUNCTION: BCS2LibClose
 *
 *  DESCRIPTION:	Closes the BarCodeScanner libary, frees globals.
 *								Turns off module power
 *
 *						***IMPORTANT***
 *						May be called only if BCS2LibOpen succeeded.
 *
 *						If other applications still have the library open, decrements
 *						the reference count and returns errBCS2LibStillOpen.
 *
 *  LIBRARY DEVELOPER NOTES:
 *
 *						The library's "open" and "close" functions should *not* take an excessive
 *						amount of time to complete.  If the processing time for either of these
 *						is lengthy, consider creating additional library API function(s) to handle
 *						the time-consuming chores.
 *
 *  PARAMETERS:	
 *						refNum				-- BarCodeScanner library reference number returned by SysLibLoad()
 *													   or SysLibFind().
 *
 *  CALLED BY:		Whoever wants to close the BarCodeScanner library
 *
 *  RETURNS:	errNone							-- no error
 *						errBCS2LibStillOpen	-- library is still open by others (no error)
 *
 *  CREATED:	2-Dec-2003 
 *
 *  BY: 			Hemon Dey
 *
 *  REVISION HISTORY:
 *			Name	Date		Description
 *			----	----		-----------
 *
 *************************************************************/
 extern Err BCS2LibClose(UInt16 refNum)
				SAMPLE_LIB_TRAP(sysLibTrapClose);

/************************************************************
 *
 *  FUNCTION: 		BCS2LibSleep
 *
 *  DESCRIPTION:	Handles system sleep notification.
 *								Turns off module power
 *
 *  PARAMETERS:		refNum		-- BarCodeScanner library reference number
 *
 *  CALLED BY:		System
 *
 *  RETURNS:			errNone		-- no error
 *
 *  CREATED:			2-Dec-03 
 *
 *  BY: 					Hemon Dey
 *
 *  REVISION HISTORY:
 *			Name	Date		Description
 *			----	----		-----------
 *
 *************************************************************/
extern Err BCS2LibSleep(UInt16 refNum)
				SAMPLE_LIB_TRAP(sysLibTrapSleep);

/************************************************************
 *
 *  FUNCTION: BCS2LibWake
 *
 *  DESCRIPTION:	Handles system wake notification
 *								Does not turn on module power
 *
 *  PARAMETERS:	refNum		-- BarCodeScanner library reference number
 *
 *  CALLED BY:	System
 *
 *  RETURNS:		errNone		-- no error
 *
 *  CREATED:		2-Dec-03 
 *
 *  BY: 				Hemon Dey
 *
 *  REVISION HISTORY:
 *			Name	Date		Description
 *			----	----		-----------
 *
 *************************************************************/
extern Err BCS2LibWake(UInt16 refNum)
				SAMPLE_LIB_TRAP(sysLibTrapWake);


//--------------------------------------------------
// Custom library API functions
//--------------------------------------------------
	
/************************************************************
 *
 *  FUNCTION: 		BCS2LibGetLibAPIVersion
 *
 *  DESCRIPTION:	Get the BCS2 library API version.  
 *
 *  PARAMETERS:		refNum		-- BarCodeScanner library reference number
 *								dwVerP		-- pointer to variable for storing the version number
 *
 *  CALLED BY:		Anyone wishing to get our library API version
 *
 *  RETURNS:			errNone		-- no error
 *
 *  CREATED:			2-Dec-03 
 *
 *  BY: 					Hemon Dey
 *
 * LIBRARY VERSION
 *
 * The library version scheme follows the system versioning scheme.
 * See sysMakeROMVersion and friends in SystemMgr.h.
 *
 * For reference:
 *
 * 0xMMmfsbbb, where MM is major version, m is minor version
 * f is bug fix, s is stage: 3-release,2-beta,1-alpha,0-development,
 * bbb is build number for non-releases 
 * V1.12b3   would be: 0x01122003
 * V2.00a2   would be: 0x02001002
 * V1.01     would be: 0x01013000
 *
 *  REVISION HISTORY:
 *			Name	Date		Description
 *			----	----		-----------
 *************************************************************/
extern Err BCS2LibGetLibAPIVersion(UInt16 refNum, UInt32 * dwVerP)
				SAMPLE_LIB_TRAP(BCS2LibTrapGetLibAPIVersion);
	
/************************************************************
 *
 *  FUNCTION: 		BCS2LibTriggerOn
 *
 *  DESCRIPTION:	Trigger on the BCS2 module.
 *								Turns on scanner power if not already on
 *
 *  PARAMETERS:		refNum						-- BarCodeScanner library reference number
 *
 *  CALLED BY:		Anyone wishing to trigger the BCS2 module to start scanning
 *
 *  RETURNS:			errNone						-- no error
 *								errBCS2LibNotOpen	-- the library is not open
 *
 *
 *  CREATED:			2-Dec-03 
 *
 *  BY: 					Hemon Dey
 *
 *  REVISION HISTORY:
 *			Name	Date		Description
 *			----	----		-----------
 *
 *************************************************************/
extern Err BCS2LibTriggerOn(UInt16 refNum)
				SAMPLE_LIB_TRAP(BCS2LibTrapTriggerOn);

/************************************************************
 *
 *  FUNCTION: 		BCS2LibTriggerOff
 *
 *  DESCRIPTION:	This function does nothing. Just here for compatibility with BCS1
 *
 *  PARAMETERS:		refNum						-- BarCodeScanner library reference number
 *
 *  CALLED BY:		Anyone wishing to trigger the BCS2 module to start scanning
 *
 *  RETURNS:			errNone						-- no error
 *								errBCS2LibNotOpen	-- the library is not open
 *
 *
 *  CREATED:			2-Dec-03 
 *
 *  BY: 					Hemon Dey
 *
 *  REVISION HISTORY:
 *			Name	Date		Description
 *			----	----		-----------
 *
 *************************************************************/
extern Err BCS2LibTriggerOff(UInt16 refNum)
				SAMPLE_LIB_TRAP(BCS2LibTrapTriggerOff);


/************************************************************
 *
 *  FUNCTION: 		BCS2LibReset
 *
 *  DESCRIPTION:	Resets the BCS2 module (cycles power to scanner module)
 *
 *  PARAMETERS:		refNum				-- BarCodeScanner library reference number
 *
 *  CALLED BY:		Anyone wishing to reset the BCS2 module.
 *
 *  RETURNS:			errNone						-- no error
 *								errBCS2LibNotOpen	-- the library is not open
 *
 *  CREATED:			2-Dec-03 
 *
 *  BY: 					Hemon Dey
 *
 *  REVISION HISTORY:
 *			Name	Date		Description
 *			----	----		-----------
 *
 *************************************************************/		
extern Err BCS2LibReset(UInt16 refNum)
				SAMPLE_LIB_TRAP(BCS2LibTrapReset);

		
/************************************************************
 *
 *  FUNCTION: BCS2LibSetToFactoryDefaults
 *
 *  DESCRIPTION:	Sets the BCS2 module to its ACEECA's factory defaults.
 *								NB. These are the same as Metrologic defaults
 *
 *  PARAMETERS:		refNum							-- BarCodeScanner library reference number
 *
 *  CALLED BY:		Anyone wishing set the BCS module to its factory defaults.
 *
 *  RETURNS:			errNone							-- no error
 *								errBCS2LibNotOpen		-- the library is not open
 *
 *  CREATED:			2-Dec-03 
 *
 *  BY: 					Hemon Dey
 *
 *  REVISION HISTORY:
 *			Name	Date		Description
 *			----	----		-----------
 *
 *************************************************************/
extern Err BCS2LibSetToFactoryDefaults(UInt16 refNum)
				SAMPLE_LIB_TRAP(BCS2LibTrapSetToFactoryDefaults);

/************************************************************
 *
 *  FUNCTION: BCS2LibChangeSettings
 *
 *  DESCRIPTION:	Changes the settings to the BCS2 module.
 *
 *  PARAMETERS:	refNum		-> 	BarCodeScanner library reference number
 *								str				->	The configuration string (one or more 3-charcter commands for IS4120)
 *								numBytes 	-> 	The size of the configuration string (3,6,9,...)
  *
 *  CALLED BY:		Anyone wishing to reconfigure the BCS module.
 *
 *  RETURNS:			errNone							-- no error
 *								errBCS2LibNotOpen		-- the library is not open
 *
 *  CREATED:			2-Dec-03 
 *
 *  BY: 					Hemon Dey
 *
 *  REVISION HISTORY:
 *			Name	Date		Description
 *			----	----		-----------
 *
 *************************************************************/
extern Err BCS2LibChangeSettings(UInt16 refNum, UInt8* str, UInt16 numBytes)
				SAMPLE_LIB_TRAP(BCS2LibTrapChangeSettings);


// For loading the library in Palm OS Mac emulation mode
extern Err BCS2LibInstall(UInt16 refNum, SysLibTblEntryPtr entryP);


#ifdef __cplusplus 
}
#endif


#endif	// __BCS2_LIB_H__
